@@ -488,7 +488,8 @@ VisualCell *NotebookCanvas::add_cell(Glib::RefPtr<DataCell> dc, Glib::RefPtr<Dat
 			std::ostringstream fstr;
 			fstr << THEFONT << " " << 12+(doc.font_step*2); 
 			newcell->inbox=manage( new ExpressionInput(dc->textbuf, fstr.str()) );
-			Gtk::VBox::BoxList::iterator newit=bl.insert(gtkit, *newcell->inbox);
+//			Gtk::VBox::BoxList::iterator newit=
+			bl.insert(gtkit, *newcell->inbox);
 
 			gtk_box_set_child_packing(((Gtk::Box *)(&scrollbox))->gobj(), 
 											  ((Gtk::Widget *)(newcell->inbox))->gobj(),
@@ -517,7 +518,8 @@ VisualCell *NotebookCanvas::add_cell(Glib::RefPtr<DataCell> dc, Glib::RefPtr<Dat
 		case DataCell::c_texcomment:
 		case DataCell::c_comment: {
 			newcell->outbox=manage( new TeXView(dc->texbuf) );
-			Gtk::VBox::BoxList::iterator newit=bl.insert(gtkit, *newcell->outbox);
+//			Gtk::VBox::BoxList::iterator newit=
+			bl.insert(gtkit, *newcell->outbox);
          // REPORT BUG: this sometimes segfaults
          //			(*newit).set_options(Gtk::PACK_SHRINK);
 			gtk_box_set_child_packing(((Gtk::Box *)(&scrollbox))->gobj(), 
@@ -542,7 +544,8 @@ VisualCell *NotebookCanvas::add_cell(Glib::RefPtr<DataCell> dc, Glib::RefPtr<Dat
 				sigc::bind(
 					sigc::mem_fun(doc, &XCadabra::handle_tex_update_request), this, newcell));
 
-			Gtk::VBox::BoxList::iterator newit=bl.insert(gtkit, *newcell->texbox);
+//			Gtk::VBox::BoxList::iterator newit=
+			bl.insert(gtkit, *newcell->texbox);
 
 			gtk_box_set_child_packing(((Gtk::Box *)(&scrollbox))->gobj(), 
 											  ((Gtk::Widget *)(newcell->texbox))->gobj(),
@@ -1239,7 +1242,7 @@ void XCadabra::on_help_about()
 #endif
 
 	std::vector<std::string> authors;
-	authors.push_back("Kasper Peeters <kasper.peeters@aei.mpg.de>\n");
+	authors.push_back("Kasper Peeters <kasper.peeters@phi-sci.com>\n");
 	authors.push_back("with contributions by:");
 	authors.push_back("\tJosé M. Martín-García");
 	authors.push_back("\tJames Allen");
@@ -1593,7 +1596,8 @@ Glib::RefPtr<DataCell> XCadabra::add_cell(Glib::RefPtr<DataCell> newcell, Glib::
 			}
 		}
 
-	Gtk::Allocation al=get_allocation();
+//	Gtk::Allocation al=
+	get_allocation();
 
 	try {
 		switch(newcell->cell_type) {
@@ -2659,10 +2663,10 @@ std::string XCadabra::save(const std::string& fn) const
 		return "Cannot open file for writing.";
 		}
 	else {
-		str << "% Cadabra notebook version 1.1\n"
+		str << "% Cadabra notebook version 1.2\n"
 			 << "\\documentclass[11pt]{article}\n"
 			 << "\\usepackage[textwidth=460pt, textheight=660pt]{geometry}\n"
-			 << "\\usepackage[usenames]{color}\n"
+			 << "\\usepackage[usenames,dvipsnames]{color}\n"
 			 << "\\usepackage{amssymb}\n"
 			 << "\\usepackage[parfill]{parskip}\n"
 			 << "\\usepackage{breqn}\n"
@@ -2793,7 +2797,9 @@ std::string XCadabra::load(const std::string& fn, bool ignore_nonexistence)
 		std::getline(str,ln);
 		if(ln.substr(0,30)!="% Cadabra notebook version 1.0") {
 			if(ln.substr(0,30)!="% Cadabra notebook version 1.1") {
-				return "Not in Cadabra notebook version <= 1.1 format.";
+				if(ln.substr(0,30)!="% Cadabra notebook version 1.2") {
+					return "Not in Cadabra notebook version <= 1.2 format.";
+					}
 				}
 			}
 
@@ -3284,7 +3290,7 @@ std::string XCadabra::load_config()
 			  if(rl.size()>0 && rl[0]=='#')
 					continue;
 
-			  unsigned int pos=rl.find(":=");
+			  size_t pos=rl.find(":=");
 			  if(pos==std::string::npos) {
 					str << "Error parsing ~/.xcadabra on line " << line << std::endl;
 					return str.str();
