@@ -698,22 +698,23 @@ void algorithm::pushup_multiplier(iterator it)
 		if(*it->name=="\\sum") {
 //			txtout << "SUM" << std::endl;
 			sibling_iterator sib=tr.begin(it);
+			multiplier_t sum_multiplier=*it->multiplier;
+			::one(it->multiplier);
 			while(sib!=tr.end(it)) {
-				multiply(sib->multiplier, *it->multiplier);
+				multiply(sib->multiplier, sum_multiplier);
 //				txtout << "going up" << std::endl;
 				pushup_multiplier(tr.parent(it));
 //				txtout << "back and back up" << std::endl;
-				pushup_multiplier(sib);
+//				pushup_multiplier(sib);
 //				txtout << "back" << std::endl;
 				++sib;
 				}
-			::one(it->multiplier);
 			}
 		else {
 //			txtout << "PUSHUP: " << *it->name << std::endl;
 			if(tr.is_valid(tr.parent(it))) {
 //				txtout << "test propinherit" << std::endl;
-				iterator tmp=tr.parent(it);
+//				iterator tmp=tr.parent(it);
 				// tmp not always valid?!? This one crashes hard with a loop!?!
 //				txtout << " of " << *tmp->name << std::endl;
 				const PropertyInherit *pin=properties::get<PropertyInherit>(tr.parent(it));
@@ -823,7 +824,7 @@ bool algorithm::check_consistency(iterator it) const
 	w1.start();
 	debugout << "checking consistency ... " << std::flush;
 	assert(*it->name=="\\expression");
-	iterator entry=it;
+//	iterator entry=it;
 	iterator end=it;
 	end.skip_children();
 	++end;
@@ -1777,10 +1778,13 @@ void cleanup_expression(exptree& tr)
 void cleanup_expression(exptree& tr, exptree::iterator& it)
 	{
 //	txtout << "cleanup called on " << *it->name << std::endl;
+//	tr.print_recursive_treeform(txtout, it);
 	ratrewrite rr(tr, tr.end());
 	rr.apply_recursive(it,false);
+//	tr.print_recursive_treeform(txtout, it);
 	reduce_sub rsub(tr, tr.end());
 	rsub.apply_recursive(it, false);
+//	tr.print_recursive_treeform(txtout, it);
 	reduce_div rdiv(tr, tr.end());
 	rdiv.apply_recursive(it, false);
 
@@ -1794,6 +1798,8 @@ void cleanup_sums_products(exptree& tr, exptree::iterator& it)
 	sumflatten sf(tr, tr.end());
 	sf.make_consistent_only=true;
 	sf.apply_recursive(it, false);
+//	txtout << "one" << std::endl;
+//	tr.print_recursive_treeform(txtout, it);
 	prodflatten pf(tr, tr.end());
 	pf.make_consistent_only=true;
 	pf.apply_recursive(it, false);
@@ -1867,18 +1873,20 @@ void cleanup_nests(exptree&tr, exptree::iterator &it, bool ignore_bracket_types)
 //		txtout << tr.begin(it)->fl.bracket << " " << it->fl.bracket << std::endl;
 		if(*(tr.parent(it)->name)=="\\sum" && (ignore_bracket_types || tr.begin(it)->fl.bracket==it->fl.bracket) ) {
 			// WARNING, this is a copy of code in sumflatten!
+//			txtout << "still ok?" << std::endl;
+//			tr.print_recursive_treeform(txtout, tr.begin());
 			exptree::sibling_iterator facs=tr.begin(tr.parent(it));
 			str_node::bracket_t btype_par=facs->fl.bracket;
 			exptree::sibling_iterator terms=tr.begin(it);
 			while(terms!=tr.end(it)) {
-				multiplier_t tfac=(*terms->multiplier)*(*it->multiplier);
-				terms->multiplier=rat_set.insert(tfac).first;
+				multiply(terms->multiplier,*it->multiplier);
 				terms->fl.bracket=btype_par;
 				++terms;
 				}
 			tr.flatten(it);
 			// FIXME: this is dangerous:
 			it=tr.parent(tr.erase(it));
+//			tr.print_recursive_treeform(txtout, tr.begin());
 			}
 		return;
 		}
