@@ -1,7 +1,7 @@
 /* 
 
 	Cadabra: a field-theory motivated computer algebra system.
-	Copyright (C) 2001-2009  Kasper Peeters <kasper.peeters@aei.mpg.de>
+	Copyright (C) 2001-2011  Kasper Peeters <kasper.peeters@aei.mpg.de>
 
    This program is free software: you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -100,7 +100,7 @@ int exchange::collect_identical_tensors(exptree& tr, exptree::iterator it,
 			}
 		if(i==idts.size()) {
 			identical_tensors_t ngr;
-			ngr.comm=properties::get_composite<SelfCommutingBehaviour>(sib);
+			ngr.comm=properties::get_composite<SelfCommutingBehaviour>(sib, true);
 			ngr.spino=properties::get_composite<Spinor>(sib);
 			ngr.tab=properties::get_composite<TableauBase>(sib);
 			ngr.traceless=properties::get_composite<Traceless>(sib);
@@ -133,7 +133,7 @@ unsigned int exchange::possible_singlets(exptree& tr, exptree::iterator it)
 	LiE::LiE_t lie;
 	// Figure out the algebra from one of the indices.
 	exptree::index_iterator indit=tr.begin_index(idts[0].tensors[0]);
-	const numerical::Integer *iprop=properties::get<numerical::Integer>(indit);
+	const numerical::Integer *iprop=properties::get<numerical::Integer>(indit, true);
 	if(!iprop) 
 		throw consistency_error("Need to know about the range of the " + *indit->name + " index.");
 
